import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const xValue = d => d.Cases;
  const yValue = d => d.State;
  const margin = {top: 60, right: 20, bottom: 65, left: 150};
  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;
	
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(.4);
  
  const formatNumber = number => 
  	format('.2s')(number)
  		.toUpperCase();
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(formatNumber)
  	.tickSize(-innerHeight)
  	.ticks(5);
  
	const yAxis = axisLeft(yScale);
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  g.append('g').call(yAxis)
  	.selectAll('.domain, .tick line')
  		.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG
  	.selectAll('.domain')
  		.remove();
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  	.attr('y', d => yScale(yValue(d)))
  	.attr('width', d => xScale(xValue(d)))
  	.attr('height', yScale.bandwidth());
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -15)
  	.text('States with most covid-19 cases');
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', innerWidth / 2)
  	.attr('y', 55)
  	.attr('fill', 'black')
  	.text('Cases');
}


csv('data.csv').then(data => {
  data.forEach(d => {
  	d.Cases = +d.Cases;
  })
	render(data);
})




































